Structs
- Extension
Manager - Manages extension points and their registered implementations.
- Extension
Point - Describes a named slot where extensions can be registered.
Enums
- Extension
Kind - A type-safe wrapper for the different kinds of extensions that can be
registered. This replaces the Python/TypeScript
Anyapproach with Rust enums so the type system enforces correctness at compile time.